@@ -455,11 +455,11 @@ static int CommonWrite(Tcl_Interp *interp,
                  const char *filename, Tcl_Obj *format,
                  tkimg_MFile *handle, Tk_PhotoImageBlock *blockPtr);
 
-static int ParseFormatOpts (interp, format, opts)
-    Tcl_Interp *interp;
-    Tcl_Obj *format;
-    FMTOPT *opts;
-{
+static int ParseFormatOpts(
+    Tcl_Interp *interp,
+    Tcl_Obj *format,
+    FMTOPT *opts
+) {
     static const char *const pcxOptions[] = {
         "-compression", "-verbose", NULL 
     };
@@ -546,12 +546,12 @@ static int ObjMatch(
     return CommonMatch(&handle, widthPtr, heightPtr, NULL);
 }
 
-static int CommonMatch(handle, widthPtr, heightPtr, pcxHeaderPtr)
-    tkimg_MFile *handle;
-    int   *widthPtr;
-    int   *heightPtr;
-    PCXHEADER *pcxHeaderPtr;
-{
+static int CommonMatch(
+    tkimg_MFile *handle,
+    int   *widthPtr,
+    int   *heightPtr,
+    PCXHEADER *pcxHeaderPtr
+) {
     PCXHEADER ph;
     Int offset_x, offset_y;
 
@@ -579,20 +579,19 @@ static int CommonMatch(handle, widthPtr, heightPtr, pcxHeaderPtr)
     return 1;
 }
 
-static int ChnRead(interp, chan, filename, format, imageHandle,
-                   destX, destY, width, height, srcX, srcY)
-    Tcl_Interp *interp;         /* Interpreter to use for reporting errors. */
-    Tcl_Channel chan;           /* The image channel, open for reading. */
-    const char *filename;       /* The name of the image file. */
-    Tcl_Obj *format;            /* User-specified format object, or NULL. */
-    Tk_PhotoHandle imageHandle; /* The photo image to write into. */
-    int destX, destY;           /* Coordinates of top-left pixel in
+static int ChnRead(
+    Tcl_Interp *interp,         /* Interpreter to use for reporting errors. */
+    Tcl_Channel chan,           /* The image channel, open for reading. */
+    const char *filename,       /* The name of the image file. */
+    Tcl_Obj *format,            /* User-specified format object, or NULL. */
+    Tk_PhotoHandle imageHandle, /* The photo image to write into. */
+    int destX, int destY,       /* Coordinates of top-left pixel in
                                  * photo image to be written to. */
-    int width, height;          /* Dimensions of block of photo image to
+    int width, int height,      /* Dimensions of block of photo image to
                                  * be written to. */
-    int srcX, srcY;             /* Coordinates of top-left pixel to be used
+    int srcX, int srcY          /* Coordinates of top-left pixel to be used
                                  * in image being read. */
-{
+) {
     tkimg_MFile handle;
 
     handle.data = (char *) chan;
@@ -603,16 +602,15 @@ static int ChnRead(interp, chan, filename, format, imageHandle,
                        width, height, srcX, srcY);
 }
 
-static int ObjRead (interp, data, format, imageHandle,
-                    destX, destY, width, height, srcX, srcY)
-    Tcl_Interp *interp;
-    Tcl_Obj *data;
-    Tcl_Obj *format;
-    Tk_PhotoHandle imageHandle;
-    int destX, destY;
-    int width, height;
-    int srcX, srcY;
-{
+static int ObjRead(
+    Tcl_Interp *interp,
+    Tcl_Obj *data,
+    Tcl_Obj *format,
+    Tk_PhotoHandle imageHandle,
+    int destX, int destY,
+    int width, int height,
+    int srcX, int srcY
+) {
     tkimg_MFile handle;
 
     tkimg_ReadInit (data, 10, &handle);
@@ -620,20 +618,19 @@ static int ObjRead (interp, data, format, imageHandle,
                        destX, destY, width, height, srcX, srcY);
 }
 
-static int CommonRead (interp, handle, filename, format, imageHandle,
-                       destX, destY, width, height, srcX, srcY)
-    Tcl_Interp *interp;         /* Interpreter to use for reporting errors. */
-    tkimg_MFile *handle;        /* The image file, open for reading. */
-    const char *filename;       /* The name of the image file. */
-    Tcl_Obj *format;            /* User-specified format object, or NULL. */
-    Tk_PhotoHandle imageHandle; /* The photo image to write into. */
-    int destX, destY;           /* Coordinates of top-left pixel in
+static int CommonRead(
+    Tcl_Interp *interp,         /* Interpreter to use for reporting errors. */
+    tkimg_MFile *handle,        /* The image file, open for reading. */
+    const char *filename,       /* The name of the image file. */
+    Tcl_Obj *format,            /* User-specified format object, or NULL. */
+    Tk_PhotoHandle imageHandle, /* The photo image to write into. */
+    int destX, int destY,       /* Coordinates of top-left pixel in
                                  * photo image to be written to. */
-    int width, height;          /* Dimensions of block of photo image to
+    int width, int height,      /* Dimensions of block of photo image to
                                  * be written to. */
-    int srcX, srcY;             /* Coordinates of top-left pixel to be used
+    int srcX, int srcY          /* Coordinates of top-left pixel to be used
                                  * in image being read. */
-{
+) {
     int fileWidth, fileHeight;
     int outWidth, outHeight;
     int retCode = TCL_OK;
@@ -752,13 +749,13 @@ static int StringWrite(
     return result;
 }
 
-static int CommonWrite (interp, filename, format, handle, blockPtr)
-    Tcl_Interp *interp;
-    const char *filename;
-    Tcl_Obj *format;
-    tkimg_MFile *handle;
-    Tk_PhotoImageBlock *blockPtr;
-{
+static int CommonWrite(
+    Tcl_Interp *interp,
+    const char *filename,
+    Tcl_Obj *format,
+    tkimg_MFile *handle,
+    Tk_PhotoImageBlock *blockPtr
+) {
     int     x, y, nchan, nBytes;
     int     redOffset, greenOffset, blueOffset, alphaOffset;
     UByte   *pixelPtr, *pixRowPtr;
