@@ -375,11 +375,11 @@ static Boln readUByteFile (Tcl_Interp *interp, tkimg_MFile *handle, UByte *buf,
     return TRUE;
 }
 
-static int ParseFormatOpts (interp, format, opts)
-    Tcl_Interp *interp;
-    Tcl_Obj *format;
-    FMTOPT *opts;
-{
+static int ParseFormatOpts(
+    Tcl_Interp *interp,
+    Tcl_Obj *format,
+    FMTOPT *opts
+) {
     static const char *const ppmOptions[] = {
          "-verbose", "-min", "-max", "-gamma", "-scanorder", "-ascii", NULL
     };
@@ -387,7 +387,6 @@ static int ParseFormatOpts (interp, format, opts)
     char *optionStr;
     Tcl_Obj **objv;
     int boolVal;
-    int intVal;
     double doubleVal;
 
     /* Initialize options with default values. */
@@ -548,12 +547,12 @@ static int ObjMatch(
     return CommonMatch(&handle, widthPtr, heightPtr, &dummy);
 }
 
-static int CommonMatch(handle, widthPtr, heightPtr, maxIntensityPtr)
-    tkimg_MFile *handle;
-    int *widthPtr;
-    int *heightPtr;
-    int *maxIntensityPtr;
-{
+static int CommonMatch(
+    tkimg_MFile *handle,
+    int *widthPtr,
+    int *heightPtr,
+    int *maxIntensityPtr
+) {
     Boln dummy;
     return ReadPPMFileHeader(handle, widthPtr, heightPtr, maxIntensityPtr, &dummy);
 }
@@ -579,20 +578,19 @@ static int CommonMatch(handle, widthPtr, heightPtr, maxIntensityPtr)
  *----------------------------------------------------------------------
  */
 
-static int ChnRead(interp, chan, filename, format, imageHandle,
-                    destX, destY, width, height, srcX, srcY)
-    Tcl_Interp *interp;         /* Interpreter to use for reporting errors. */
-    Tcl_Channel chan;           /* The image file, open for reading. */
-    const char *filename;       /* The name of the image file. */
-    Tcl_Obj *format;            /* User-specified format string, or NULL. */
-    Tk_PhotoHandle imageHandle; /* The photo image to write into. */
-    int destX, destY;           /* Coordinates of top-left pixel in
+static int ChnRead(
+    Tcl_Interp *interp,         /* Interpreter to use for reporting errors. */
+    Tcl_Channel chan,           /* The image file, open for reading. */
+    const char *filename,       /* The name of the image file. */
+    Tcl_Obj *format,            /* User-specified format string, or NULL. */
+    Tk_PhotoHandle imageHandle, /* The photo image to write into. */
+    int destX, int destY,       /* Coordinates of top-left pixel in
                                  * photo image to be written to. */
-    int width, height;          /* Dimensions of block of photo image to
+    int width, int height,      /* Dimensions of block of photo image to
                                  * be written to. */
-    int srcX, srcY;             /* Coordinates of top-left pixel to be used
+    int srcX, int srcY          /* Coordinates of top-left pixel to be used
                                  * in image being read. */
-{
+) {
     tkimg_MFile handle;
 
     handle.data = (char *) chan;
@@ -602,16 +600,15 @@ static int ChnRead(interp, chan, filename, format, imageHandle,
                        destX, destY, width, height, srcX, srcY);
 }
 
-static int ObjRead (interp, data, format, imageHandle,
-                    destX, destY, width, height, srcX, srcY)
-    Tcl_Interp *interp;
-    Tcl_Obj *data;
-    Tcl_Obj *format;
-    Tk_PhotoHandle imageHandle;
-    int destX, destY;
-    int width, height;
-    int srcX, srcY;
-{
+static int ObjRead(
+    Tcl_Interp *interp,
+    Tcl_Obj *data,
+    Tcl_Obj *format,
+    Tk_PhotoHandle imageHandle,
+    int destX, int destY,
+    int width, int height,
+    int srcX, int srcY
+) {
     tkimg_MFile handle;
 
     tkimg_ReadInit (data, 'P', &handle);
@@ -619,20 +616,19 @@ static int ObjRead (interp, data, format, imageHandle,
                        destX, destY, width, height, srcX, srcY);
 }
 
-static int CommonRead (interp, handle, filename, format, imageHandle,
-                       destX, destY, width, height, srcX, srcY)
-    Tcl_Interp *interp;         /* Interpreter to use for reporting errors. */
-    tkimg_MFile *handle;                /* The image file, open for reading. */
-    const char *filename;       /* The name of the image file. */
-    Tcl_Obj *format;            /* User-specified format string, or NULL. */
-    Tk_PhotoHandle imageHandle; /* The photo image to write into. */
-    int destX, destY;           /* Coordinates of top-left pixel in
+static int CommonRead(
+    Tcl_Interp *interp,         /* Interpreter to use for reporting errors. */
+    tkimg_MFile *handle,                /* The image file, open for reading. */
+    const char *filename,       /* The name of the image file. */
+    Tcl_Obj *format,            /* User-specified format string, or NULL. */
+    Tk_PhotoHandle imageHandle, /* The photo image to write into. */
+    int destX, int destY,       /* Coordinates of top-left pixel in
                                  * photo image to be written to. */
-    int width, height;          /* Dimensions of block of photo image to
+    int width, int height,      /* Dimensions of block of photo image to
                                  * be written to. */
-    int srcX, srcY;             /* Coordinates of top-left pixel to be used
+    int srcX, int srcY          /* Coordinates of top-left pixel to be used
                                  * in image being read. */
-{
+) {
     Int fileWidth, fileHeight, maxIntensity;
     Int x, y, c;
     int type;
@@ -821,12 +817,12 @@ static int CommonRead (interp, handle, filename, format, imageHandle,
  *----------------------------------------------------------------------
  */
 
-static int ChnWrite (interp, filename, format, blockPtr)
-    Tcl_Interp *interp;
-    const char *filename;
-    Tcl_Obj *format;
-    Tk_PhotoImageBlock *blockPtr;
-{
+static int ChnWrite(
+    Tcl_Interp *interp,
+    const char *filename,
+    Tcl_Obj *format,
+    Tk_PhotoImageBlock *blockPtr
+) {
     Tcl_Channel chan;
     tkimg_MFile handle;
     int result;
@@ -882,13 +878,13 @@ static int writeAsciiRow (tkimg_MFile *handle, const unsigned char *scanline, in
     return nBytes;
 }
 
-static int CommonWrite (interp, filename, format, handle, blockPtr)
-    Tcl_Interp *interp;
-    const char *filename;
-    Tcl_Obj *format;
-    tkimg_MFile *handle;
-    Tk_PhotoImageBlock *blockPtr;
-{
+static int CommonWrite(
+    Tcl_Interp *interp,
+    const char *filename,
+    Tcl_Obj *format,
+    tkimg_MFile *handle,
+    Tk_PhotoImageBlock *blockPtr
+) {
     int w, h;
     int redOff, greenOff, blueOff, nBytes;
     unsigned char *scanline, *scanlinePtr;
@@ -966,14 +962,14 @@ static int CommonWrite (interp, filename, format, handle, blockPtr)
  */
 
 static int
-ReadPPMFileHeader (handle, widthPtr, heightPtr, maxIntensityPtr, isAsciiPtr)
-    tkimg_MFile *handle;        /* Image file to read the header from */
-    int *widthPtr, *heightPtr;  /* The dimensions of the image are
-                                 * returned here. */
-    int *maxIntensityPtr;       /* The maximum intensity value for
+ReadPPMFileHeader(
+    tkimg_MFile *handle,        /* Image file to read the header from */
+    int *widthPtr, int *heightPtr,  /* The dimensions of the image are
+                                     * returned here. */
+    int *maxIntensityPtr,       /* The maximum intensity value for
                                  * the image is stored here. */
-    Boln *isAsciiPtr;
-{
+    Boln *isAsciiPtr
+) {
 #define BUFFER_SIZE 1000
     char buffer[BUFFER_SIZE];
     int i, numFields;
